==> spml_0.2.1-1.tar.gz: spml-0.2.1/src/w_module.f90 <==
!----------------------------------------------------------------------
!     Copyright (c) 2002 Shin-ichi Takehiro. All rights reserved.
!----------------------------------------------------------------------
!ɽ  w_module
!
!  2002/02/02  ݹ  1 
!      2002/02/07  ݹ  ؿ,ѿ̾ѹ
!      2002/03/25  ݹ  ⥸塼̾ѹ
!      2002/05/25  ݹ  ʻɸ̤٤̿̾ˡѹ
!      2002/10/07  ݹ  , ̺ɸʬɲ
!
!         Ѵʻǡ, ڥȥǡ礭Ϸᤦ
!
module w_module

  use w_base_module
  use w_deriv_module, w_Initial => w_deriv_initial
  use w_integral_module

  private

  public w_Initial                            ! 

  public x_Lon, y_Lat                         ! ʻҺɸ
  public x_Lon_weight, y_Lat_Weight           ! ʻҺɸŤ
  public xy_Lon, xy_Lat                       ! ʻҺɸ(im,jm)
  public xy_w, w_xy, l_nm, nm_l               ! Ѵؿ

  public rn, irm                              ! ץ饷/ʬ黻
  public w_Lapla_w, w_LaplaInv_w              ! ץ饷ȵձ黻
  public w_DLon_w                             ! ʬ
  public xy_GradLon_w, xy_GradLat_w           ! ۷ʬ
  public w_DivLon_xy, w_DivLat_xy             ! ȯʬ
  public w_Div_xy_xy                          ! ȯʬ
  public w_Jacobian_w_w                       ! 䥳ӥ
  public xy_GradLambda_w, xy_GradMu_w         ! ۷ʬ(,̺ɸ)
  public w_DivLambda_xy, w_DivMu_xy           ! ȯʬ(,̺ɸ)

  public IntLonLat_xy                         ! ٷʬ
  public y_IntLon_xy, IntLon_x                ! ʬ    
  public x_IntLat_xy, IntLat_y                ! ʬ    
  public AvrLonLat_xy                         ! ٷʿ
  public y_AvrLon_xy, AvrLon_x                ! ʿ    
  public x_AvrLat_xy, AvrLat_y                ! ʿ    

end module w_module

==> spml_0.3.0-9.tar.gz: spml-0.3.0/src/w_module.f90 <==
!----------------------------------------------------------------------
!     Copyright (c) 2002 Shin-ichi Takehiro. All rights reserved.
!----------------------------------------------------------------------
!ɽ  w_module
!
!  2002/02/02  ݹ  1 
!      2002/02/07  ݹ  ؿ,ѿ̾ѹ
!      2002/03/25  ݹ  ⥸塼̾ѹ
!      2002/05/25  ݹ  ʻɸ̤٤̿̾ˡѹ
!      2002/10/07  ݹ  , ̺ɸʬɲ
!      2005/04/23  ݹ  ڥȥϥ⥸塼ɲ
!
!         Ѵʻǡ, ڥȥǡ礭Ϸᤦ
!
module w_module

  use w_base_module
  use w_deriv_module, w_Initial => w_deriv_initial
  use w_integral_module
  use w_spectrum_module

  private

  public w_Initial                            ! 

  public x_Lon, y_Lat                         ! ʻҺɸ
  public x_Lon_weight, y_Lat_Weight           ! ʻҺɸŤ
  public xy_Lon, xy_Lat                       ! ʻҺɸ(im,jm)
  public xy_w, w_xy, l_nm, nm_l               ! Ѵؿ

  public rn, irm                              ! ץ饷/ʬ黻
  public w_Lapla_w, w_LaplaInv_w              ! ץ饷ȵձ黻
  public w_DLon_w                             ! ʬ
  public xy_GradLon_w, xy_GradLat_w           ! ۷ʬ
  public w_DivLon_xy, w_DivLat_xy             ! ȯʬ
  public w_Div_xy_xy                          ! ȯʬ
  public w_Jacobian_w_w                       ! 䥳ӥ
  public xy_GradLambda_w, xy_GradMu_w         ! ۷ʬ(,̺ɸ)
  public w_DivLambda_xy, w_DivMu_xy           ! ȯʬ(,̺ɸ)

  public IntLonLat_xy                         ! ٷʬ
  public y_IntLon_xy, IntLon_x                ! ʬ    
  public x_IntLat_xy, IntLat_y                ! ʬ    
  public AvrLonLat_xy                         ! ٷʿ
  public y_AvrLon_xy, AvrLon_x                ! ʿ    
  public x_AvrLat_xy, AvrLat_y                ! ʿ    

  public nm_EnergyFromStreamfunction_w      ! ͥ륮ڥȥ           
                                            ! (ʿȿ n, Ӿȿ m )
  public n_EnergyFromStreamfunction_w       ! ͥ륮ڥȥ
                                            ! (ʿȿ n ) 
  public nm_EnstrophyFromStreamfunction_w   ! 󥹥ȥեڥȥ     
                                            ! (ʿȿ n, Ӿȿ m )
  public n_EnstrophyFromStreamfunction_w    ! 󥹥ȥեڥȥ  
                                            !  (ʿȿ n )
  public w_spectrum_VMiss                   ! »

end module w_module
